@@ -124,7 +124,7 @@ check_cran <- function(pkgs, libpath = file.path(tempdir(), "R-lib"),
   }
 
   if (getRversion() <= '2.15.2' && threads >= length(pkgs)) {
-    threads <- length(pkgs) - 1
+    threads <- max(length(pkgs) - 1L, 1L)
     message("Reducing number of threads to ", threads,
       " (number of packages to check minus one) due to a bug in mclapply in",
       " R <= 2.15.2")
@@ -213,6 +213,11 @@ collect_check_results <- function(topdir) {
   summary_out <- file(summary_filename, "w")
   on.exit(close(summary_out))
 
+  sink(summary_out)
+  print(sessionInfo())
+  cat("\n")
+  sink()
+
   for (i in seq_along(checkresults)) {
     pkgname <- names(checkresults[i])
     linetext <- paste(rep("=", 72 - nchar(pkgname)), collapse = "")
