@@ -14,11 +14,17 @@
 #'                contain the package we are interested in installing.
 #' @param git_binary A custom git-binary to use instead of default system's git
 #'                   version.
+#' @param branch  Name of branch or tag to use, if not master.
 #' @param ...        Other arguments passed on to \code{\link{install}}.
 #' @export
 #' @family package installation
+#' @examples
+#' \dontrun{
+#' install_git("git://github.com/hadley/stringr.git")
+#' install_git("git://github.com/hadley/stringr.git", branch = "stringr-0.2")
+#'}
 install_git <- function(git_url, name = NULL, subdir = NULL,
-  git_binary = NULL, ...) {
+  branch = NULL, git_binary = NULL, ...) {
 
   if (is.null(name)) {
     name <- rep(list(NULL), length(git_url))
@@ -26,7 +32,7 @@ install_git <- function(git_url, name = NULL, subdir = NULL,
 
   invisible(mapply(install_git_single, git_url, name,
     MoreArgs = list(
-      subdir = subdir, git_binary = git_binary, ...
+      subdir = subdir, git_binary = git_binary, branch = branch, ...
     )
   ))
 }
@@ -48,7 +54,7 @@ install_git <- function(git_url, name = NULL, subdir = NULL,
 #' @param ... passed on to \code{\link{install}}
 #' @keywords internal
 install_git_single <- function(git_url, name = NULL, subdir = NULL,
-  git_binary = NULL, ...) {
+  branch = NULL, git_binary = NULL, ...) {
 
   if (is.null(name)) {
     name <- gsub("\\.git$", "", basename(git_url))
@@ -65,11 +71,11 @@ install_git_single <- function(git_url, name = NULL, subdir = NULL,
   # Clone the package file from the git repository.
   # @TODO: Handle configs, this currently only supports public repos
   #        and repositories with the public SSH key set.
-  request <- system2(
-    git_binary_path,
-    args = c('clone', '--depth', '1', '--no-hardlinks', git_url,  bundle),
-    stdout = FALSE, stderr = FALSE
-  )
+  args <- c('clone', '--depth', '1', '--no-hardlinks')
+  if (!is.null(branch)) args <- c(args, "--branch", branch)
+  args <- c(args, git_url, bundle)
+
+  request <- system2(git_binary_path, args, stdout = FALSE, stderr = FALSE)
 
   # This is only looking for an error code above 0-success
   if (request > 0) {
@@ -90,7 +96,7 @@ install_git_single <- function(git_url, name = NULL, subdir = NULL,
   }
 
   # Install
-  install(pkg_path, ...)
+  install(pkg_path, local = TRUE, ...)
 }
 
 
