@@ -11,6 +11,10 @@
 #'   \item \code{with_path}: PATH environment variable
 #'   \item \code{with_par}: graphics parameters
 #' }
+#' @section Deprecation:
+#' \code{with_env} will be deprecated in devtools 1.2 and removed in
+#' devtools 1.3
+#'
 #' @param new values for setting
 #' @param code code to execute in that environment
 #'
@@ -23,6 +27,10 @@
 #' Sys.getenv("HADLEY")
 #' with_envvar(c("HADLEY" = 2), Sys.getenv("HADLEY"))
 #' Sys.getenv("HADLEY")
+#'
+#' with_envvar(c("A" = 1),
+#'   with_envvar(c("A" = 2), action = "suffix", Sys.getenv("A"))
+#' )
 NULL
 
 with_something <- function(set) {
@@ -38,24 +46,50 @@ is.named <- function(x) {
 
 # env ------------------------------------------------------------------------
 
-set_envvar <- function(envs) {
+set_envvar <- function(envs, action = "replace") {
   stopifnot(is.named(envs))
+  stopifnot(is.character(action), length(action) == 1)
+  action <- match.arg(action, c("replace", "prefix", "suffix"))
 
   old <- Sys.getenv(names(envs), names = TRUE, unset = NA)
-  
   set <- !is.na(envs)
-  if (any(set)) do.call("Sys.setenv", as.list(envs[set]))
+
+  both_set <- set & !is.na(old)
+  if (any(both_set)) {
+    if (action == "prefix") {
+      envs[both_set] <- paste(envs[both_set], old[both_set])
+    } else if (action == "suffix") {
+      envs[both_set] <- paste(old[both_set], envs[both_set])
+    }
+  }
+
+  if (any(set))  do.call("Sys.setenv", as.list(envs[set]))
   if (any(!set)) Sys.unsetenv(names(envs)[!set])
-  
+
   invisible(old)
 }
 #' @rdname with_something
+#' @param action (for \code{with_envvar} only): should new values
+#'    \code{"replace"}, \code{"suffix"}, \code{"prefix"} existing environmental
+#'    variables with the same name.
 #' @export
-with_envvar <- with_something(set_envvar)
+with_envvar <- function(new, code, action = "replace") {
+  old <- set_envvar(new, action)
+  on.exit(set_envvar(old, "replace"))
+  force(code)
+}
+
+
+with_something(set_envvar)
 
 #' @rdname with_something
 #' @export
-with_env <- with_envvar
+with_env <- function(new, code) {
+  message(
+    "with_env() will be deprecated in devtools 1.3.\n",
+    "Please use with_envvar() instead")
+  with_envvar(new, code)
+}
 
 # locale ---------------------------------------------------------------------
 
